import Vue from "vue";
import Vuex from "vuex";

Vue.use(Vuex);

export default new Vuex.Store({
    state: {
        editCmd: "", //编辑器编辑命令
        legendObj: null, //获取的相关图例数据obj

        name: "", //图名称
        folderId: "", //文件id
        folderName: "", //文件夹名称
        buildingId: "", //建筑id
        floorId: "", //楼层id
        floorMap: "", //floorMap
        floorLocalName: "", //楼层本地名称
        id: "", //图id
        graphId: "", //图graphId
        version: "", //版本号
        state: "", //图状态,  Draft: 未发布, WaitCheck: 待审核, Checked: 审核完成, Recyle: 回收站, Publish: 发布

        isPub: 0, // 用于读图 区分读取 已发布 or 未发布
        projectId: "Pj1101050029", // projectId
        categoryId: "", //类型id 用于读图
        equipmentItemList: [], // 图上相关的设备实例
        equipmentItemNum: 0, // 图上相关的设备实例的数量

        equipItemMap: {}, // 图上相关的设备实例
        equipItemNum: 0, // 图上相关的设备的数量
        zoneIteMap: {}, // 图上相关的空间实例
        zoneItemNum: 0, // 图上相关的空间实例的数量
        styleMap: {}, // 样式库信息
        objExtInfo: {}, // 设备位置信息
    },
    mutations: {
        // 修改编辑器命令
        SETCHOICELEHEND(state, data) {
            state.editCmd = data;
        },
        // 修改编辑器图例
        SETLEGENDOBJ(state, data) {
            state.legendObj = data;
        },
        // 设置项目信息
        SETPROJECT(state, data) {
            const arr = [
                "name",
                "folderId",
                "folderName",
                "buildingId",
                "floorId",
                "floorMap",
                "floorLocalName",
                "id",
                "graphId",
                "state",
                "version",
            ];
            arr.map((key) => {
                // 对传入的参数进行修改
                if (data[key] !== undefined) {
                    // @ts-ignore
                    state[key] = data[key];
                }
            });
        },
        // 设置项目id
        SETISPUB(state, val) {
            state.isPub = val; // 是否发布 用于读图
        },
        // 设置类型id
        SETCATEGROY(state, val) {
            state.folderId = val.folderId; //文件夹id
            state.name = val.name; //拓扑图名称
            state.version = val.version; //版本号
        },
        SETVERSION(state, val) {
            state.version = val; //版本号
        },
        // 增加设备实例 item
        ADDEQUIPITEM(state, item): void {
            state.equipmentItemList.push(item);
            state.equipmentItemNum = state.equipmentItemList.length;
        },
        // 删除设备实例 item
        EDITEQUIPITEM(state): void {
            // 如果设备实例数组中parent 为null 则删除该数组
            let arr1 = state.equipmentItemList;
            if (!arr1.length) return;

            for (var i = 0; i < arr1.length; i++) {
                if (!arr1[i].parent) {
                    arr1.splice(i, 1);
                    i--; //i需要自减，否则每次删除都会讲原数组索引发生变化
                }
            }
            state.equipmentItemList = arr1;
            state.equipmentItemNum = state.equipmentItemList.length;
        },
        // 初始化设备位置信息
        INITOBJEXTINFO(state, data) {
            state.objExtInfo = data;
        },
        // 初始化样式库信息
        INITSTYLE(state, data) {
            // 设备默认样式
            data.defaultEquipStyle = {
                color: "#1F2429",
                size: 12,
                url: "tognyong2020102700.svg",
                formula: JSON.stringify(['设备实例']),
            };
            state.styleMap = data;
        },
        // 添加样式信息
        ADDSTYLE(state, data) {
            // @ts-ignore
            const { id, style } = { ...data };
            // @ts-ignore
            state.styleMap[id] = style;
        },
        // 增加设备实例item
        ADDEQUIP(state, item): void {
            // @ts-ignore
            if (!state.equipItemMap[item.id]) {
                // @ts-ignore
                state.equipItemMap[item.id] = item;
                state.equipItemNum = Object.keys(state.equipItemMap).length;
            }
        },
        DELETEQUIP(state): void {
            // 如果设备实例数组中parent 为null 则删除该数组
            let arr1 = Object.keys(state.equipItemMap);
            if (!arr1.length) return;

            arr1.forEach((key) => {
                // @ts-ignore
                if (!state.equipItemMap[key].parent) {
                    // @ts-ignore
                    delete state.equipItemMap[key];
                }
            });
        },
    },
    actions: {},
    modules: {},
});
